pub struct DataEntity {
pub id: String,
pub type_: DataType,
pub dynamic_entity: Option<HashMap<String, EntityValue>>,
}Expand description
Represents a data entity with an identifier, type, and dynamic properties.
DataEntity is designed to encapsulate an entity with a unique identifier (id),
a specific type (type_), and a set of dynamic properties (dynamic_entity).
This struct is used to handle Data entities that have a predefined structure along with
additional properties that may vary.
Fields
id: StringURI to data
type_: DataTypeDefined type, if file MUST be type ‘File’
dynamic_entity: Option<HashMap<String, EntityValue>>Additional metadata
Implementations
Sourceimpl DataEntity
impl DataEntity
Sourcepub fn get_property_value(
&self,
property: &str,
) -> Option<(String, EntityValue)>
pub fn get_property_value( &self, property: &str, ) -> Option<(String, EntityValue)>
Gets ID and value of specific target property
Sourcepub fn find_value_details(
&self,
target_value: &EntityValue,
) -> Option<(String, String)>
pub fn find_value_details( &self, target_value: &EntityValue, ) -> Option<(String, String)>
pub fn get_linked_ids(&self) -> Vec<Id>